History
-------

UNRELEASED
++++++++++


0.3.1 (2020-12-19)
******************

* fixes PyPi upload error, Issue #6


0.3.0 (2020-12-19)
******************

* drop support for python 2, add 3.7, 3.8, and 3.9.


0.2.0 (2017-10-21)
++++++++++++++++++

* name change from pythonanywhere to pythonanywhere-wrapper
* Add history


0.1.1
+++++

* Add attribution for chargify-python


0.1.0
+++++

* Initial release on PyPI